Idcheckio class

Public API. Main entry of the SDK. Call these functions from you dart code to interact with Idcheckio.

Implemented types

Constructors

Idcheckio()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

activate({required String token, bool extractData = true}) → Future<void>
Activates the sdk with the given token.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preload({bool extractData = true}) → Future<void>
Preload the native models of the sdk.
override
start({required IDCheckioParams parameters, OnlineContext? onlineContext, IDCheckioTheme? theme}) → Future<IDCheckioResult>
Start the capture of one document with the given parameters.
override
startOnboarding({required String folderUid, IDCheckioTheme? theme}) → Future<void>
Start an onboarding session with the given folder uid.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited