IDCheckTheme class

Constructors

IDCheckTheme({Color? primaryColor, Color? borderColor, Color? backgroundColor, Color? foregroundColor, Color? titleColor, Color? textColor})

Properties

backgroundColor ↔ Color?
getter/setter pair
borderColor ↔ Color?
getter/setter pair
foregroundColor ↔ Color?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
primaryColor ↔ Color?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor ↔ Color?
getter/setter pair
titleColor ↔ Color?
getter/setter pair

Methods

addColorToJson(Map<String, dynamic> json, String name, Color? color) → void
colorToHex(Color color) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited