IDCheckioParams class

Params

Constructors

IDCheckioParams(IDCheckioParamsBuilder builder)

Properties

adjustCrop → bool?
final
captureMode → CaptureMode?
final
confirmAbort → bool?
final
confirmationType → ConfirmationType?
final
docType → DocumentType?
final
feedbackLevel → FeedbackLevel?
final
hashCode → int
The hash code for this object.
no setterinherited
integrityCheck → IntegrityCheck?
final
language → Language?
final
manualButtonTimer → int?
final
maxPictureFilesize → FileSize?
final
onlineConfig → OnlineConfig?
final
orientation → IDCheckioOrientation?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanBothSides → ScanBothSides?
final
sideOneExtraction → Extraction?
final
sideTwoExtraction → Extraction?
final
theme → IDCheckTheme?
final
useHd → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited