IDCheckioParamsBuilder class

Constructors

IDCheckioParamsBuilder()

Properties

adjustCrop ↔ bool?
getter/setter pair
captureMode ↔ CaptureMode?
getter/setter pair
confirmAbort ↔ bool?
getter/setter pair
confirmationType ↔ ConfirmationType?
getter/setter pair
docType ↔ DocumentType?
getter/setter pair
feedbackLevel ↔ FeedbackLevel?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
integrityCheck ↔ IntegrityCheck?
getter/setter pair
language ↔ Language?
getter/setter pair
manualButtonTimer ↔ int?
getter/setter pair
maxPictureFilesize ↔ FileSize?
getter/setter pair
onlineConfig ↔ OnlineConfig?
getter/setter pair
orientation ↔ IDCheckioOrientation?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanBothSides ↔ ScanBothSides?
getter/setter pair
sideOneExtraction ↔ Extraction?
getter/setter pair
sideTwoExtraction ↔ Extraction?
getter/setter pair
theme ↔ IDCheckTheme?
getter/setter pair
token ↔ String?
getter/setter pair
useHd ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited