IDCheckioResult class

Result

Constructors

IDCheckioResult.fromJson(Map<String, dynamic> json)

Properties

cisImageQualityStatus ↔ ImageQualityStatus?
getter/setter pair
document ↔ Document?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
images ↔ List<ImageResult>
getter/setter pair
onlineContext ↔ OnlineContext?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionInfos ↔ List<ErrorMsg>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited