OnlineConfig class

Constructors

OnlineConfig({CISType? cisType, bool? isReferenceDocument, String? folderUid, bool? biometricConsent, bool? enableManualAnalysis})

Properties

biometricConsent ↔ bool?
getter/setter pair
cisType ↔ CISType?
getter/setter pair
enableManualAnalysis ↔ bool?
getter/setter pair
folderUid ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isReferenceDocument ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited