OnlineContext class

Constructors

OnlineContext.fromJson(Map<String, dynamic> json)

Properties

attachmentDocumentUids ↔ List<String>?
getter/setter pair
attachmentTaskUids ↔ List<String>?
getter/setter pair
documentUid ↔ String?
getter/setter pair
folderUid ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
livenessStatus ↔ LivenessStatus?
getter/setter pair
referenceDocUid ↔ String?
getter/setter pair
referenceTaskUid ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskUid ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited