MethodChannelIdcheckio class

An implementation of IdcheckioPlatform that uses method channels.

Inheritance

Constructors

MethodChannelIdcheckio()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

activate({required String idToken, bool? extractData}) → Future<void>
override
analyze({required IDCheckioParams params, required String side1Uri, String? side2uri, bool? isOnline, OnlineContext? onlineContext}) → Future<IDCheckioResult>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(IDCheckioParams params) → Future<IDCheckioResult>
override
startIps(String folderUid) → Future<IDCheckioResult>
override
startOnline(IDCheckioParams params, OnlineContext? onlineContext) → Future<IDCheckioResult>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited