IdcheckioPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • IdcheckioPlatform
Implementers

Constructors

IdcheckioPlatform()
Constructs a IdcheckioPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

activate({required String idToken, bool? extractData}) → Future<void>
analyze({required IDCheckioParams params, required String side1Uri, String? side2uri, bool? isOnline, OnlineContext? onlineContext}) → Future<IDCheckioResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(IDCheckioParams params) → Future<IDCheckioResult>
startIps(String folderUid) → Future<IDCheckioResult>
startOnline(IDCheckioParams params, OnlineContext? onlineContext) → Future<IDCheckioResult>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ IdcheckioPlatform
The default instance of IdcheckioPlatform to use.
getter/setter pair