MethodChannelIdcheckio class

An implementation of IdcheckioPlatform that uses method channels. It is the bridge between dart code and ios/android one.

Implemented types

Constructors

MethodChannelIdcheckio()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

activate({required String token, bool extractData = true}) → Future<void>
Activates the sdk with the given token.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preload({bool extractData = true}) → Future<void>
Preload the native models of the sdk.
override
start({required IDCheckioParams parameters, OnlineContext? onlineContext}) → Future<IDCheckioResult>
Start the capture of one document with the given parameters.
override
startOnboarding({required String folderUid}) → Future<void>
Start an onboarding session with the given folder uid.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

captureFailedCode → const String
initFailedCode → const String