IDCheckioError class

Defines the error received from IDCheckio sdk.

Constructors

IDCheckioError(IdcheckioErrorCause cause, String details, String? message, IDCheckioErrorSubCause? subcause)
IDCheckioError.fromJson(Map<String, dynamic> json)

Properties

cause ↔ IdcheckioErrorCause
getter/setter pair
details ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subcause ↔ IDCheckioErrorSubCause?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited