IntegrityCheck class

Object storing some parameters about optional check. NFC and DocLiveness features.

Constructors

IntegrityCheck({bool? readEmrtd, bool? docLiveness})

Properties

docLiveness ↔ bool?
True to require a doc liveness after a static capture.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
readEmrtd ↔ bool?
True to ask to read nfc.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a json made with these properties.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited